@@ -19,10 +19,8 @@
 
 (require 'lichess-core)
 (require 'lichess-util)
-(require 'lichess-api)
 (require 'lichess-fen)
 (require 'lichess-board)
-(require 'lichess-announce)
 (require 'text-property-search)
 
 (defvar lichess-game--stream nil
@@ -35,9 +33,6 @@
 (defvar-local lichess-game--state nil
   "Buffer-local `lichess-game` struct containing all game state.")
 
-(defvar-local lichess-game--last-announced-idx -1
-  "Move index that was last announced to prevents duplicates.")
-
 (defvar lichess-game-buffer-mode-map
   (let ((m (make-sparse-keymap)))
     (define-key m (kbd "q") #'lichess-game-stream-stop)
@@ -55,7 +50,7 @@
 
 (define-derived-mode
  lichess-game-buffer-mode
- lichess-core-mode
+ special-mode
  "Lichess-Game"
  "Major mode for live Lichess game buffers."
  (setq truncate-lines t))
@@ -66,14 +61,14 @@
 Draws the header, board, evaluation bar (if available), and footer info.
 All parameters are derived from the buffer-local `lichess-game--state'."
   (when-let* ((state lichess-game--state)
-              (idx (plist-get state :current-idx))
-              (hist (plist-get state :fen-history)))
+              (idx (lichess-game-current-idx state))
+              (hist (lichess-game-fen-history state)))
     (let* ((fen (aref hist idx))
-           (eval-str (gethash idx (plist-get state :eval-cache)))
+           (eval-str (gethash idx (lichess-game-eval-cache state)))
            (pos
             (ignore-errors
               (lichess-fen-parse fen)))
-           (perspective (plist-get state :perspective))
+           (perspective (lichess-game-perspective state))
            (eval-label
             (cond
              ((stringp eval-str)
@@ -90,7 +85,7 @@ All parameters are derived from the buffer-local `lichess-game--state'."
                         (concat "\n" result)
                       "")))
            (highlights
-            (when-let ((sq (plist-get state :selected-square)))
+            (when-let ((sq (lichess-game-selected-square state)))
               (list sq)))
            ;; Construct Preamble: Names, Clocks, Result
            (header-parts (lichess-game--format-header state))
@@ -98,8 +93,8 @@ All parameters are derived from the buffer-local `lichess-game--state'."
            (postamble (cdr header-parts)))
       (when pos
         (let ((inhibit-read-only t))
-          (plist-put pos :eval eval-str)
-          (plist-put pos :info pos-info)
+          (setf (lichess-pos-eval pos) eval-str)
+          (setf (lichess-pos-info pos) pos-info)
           (lichess-board-render-to-buffer
            pos perspective highlights preamble postamble)
 
@@ -110,38 +105,31 @@ All parameters are derived from the buffer-local `lichess-game--state'."
         (let ((side-buf
                (get-buffer
                 (lichess-game--sidebar-buffer-name
-                 (plist-get state :id)))))
+                 (lichess-game-id state)))))
           (when (buffer-live-p side-buf)
-            (lichess-game-render-sidebar (current-buffer))))
-
-        ;; Accessibility: Announce move
-        (when (and idx
-                   (/= idx (or lichess-game--last-announced-idx -1)))
-          (setq-local lichess-game--last-announced-idx idx)
-          (lichess-announce-game-move
-           (plist-get state :moves-str) idx (plist-get pos :stm)))))))
+            (lichess-game-render-sidebar (current-buffer))))))))
 
 (defun lichess-game-history-previous ()
   "Move to the previous position in game history."
   (interactive)
   (when-let* ((state lichess-game--state)
-              (idx (plist-get state :current-idx))
-              (hist (plist-get state :fen-history)))
+              (idx (lichess-game-current-idx state))
+              (hist (lichess-game-fen-history state)))
     (when (> idx 0)
-      (plist-put state :live-mode nil)
-      (plist-put state :current-idx (1- idx))
+      (setf (lichess-game-live-mode state) nil)
+      (setf (lichess-game-current-idx state) (1- idx))
       (lichess-game-render))))
 
 (defun lichess-game-history-next ()
   "Move to the next position in game history."
   (interactive)
   (when-let* ((state lichess-game--state)
-              (idx (plist-get state :current-idx))
-              (hist (plist-get state :fen-history)))
+              (idx (lichess-game-current-idx state))
+              (hist (lichess-game-fen-history state)))
     (when (< idx (1- (length hist)))
-      (plist-put state :current-idx (1+ idx))
-      (when (= (plist-get state :current-idx) (1- (length hist)))
-        (plist-put state :live-mode t))
+      (setf (lichess-game-current-idx state) (1+ idx))
+      (when (= (lichess-game-current-idx state) (1- (length hist)))
+        (setf (lichess-game-live-mode state) t))
       (lichess-game-render))))
 
 (defun lichess-game--extract-fen (obj)
@@ -163,7 +151,7 @@ All parameters are derived from the buffer-local `lichess-game--state'."
 Handles stream replays by resetting history if a move regression is detected
 immediately after the initial summary state."
   (when-let* ((state lichess-game--state)
-              (hist (plist-get state :fen-history)))
+              (hist (lichess-game-fen-history state)))
     (let* ((len (length hist))
            (last (and (> len 0) (aref hist (1- len)))))
       ;; Detect Replay: If history has 1 item (Summary) and new FEN is earlier, reset.
@@ -172,49 +160,29 @@ immediately after the initial summary state."
               (new-fm (lichess-game--get-fen-fullmove fen)))
           (when (< new-fm last-fm)
             (setf hist (vector))
-            (plist-put state :fen-history hist))))
+            (setf (lichess-game-fen-history state) hist))))
 
       (unless (and last (string= last fen))
-        (plist-put state :fen-history (vconcat hist (vector fen)))))))
-
-(defun lichess-game-create (&rest args)
-  "Create a new game state plist with default values, overridden by ARGS."
-  (let
-      ((defaults
-        (list
-         :id nil ;; String: Game ID (or nil)
-         :variant nil ;; Alist: Variant info ((key . "standard") ...)
-         :initial-fen nil ;; String: Initial FEN
-         :initial-pos nil ;; Plist: Parsed initial position (lichess-pos)
-         :white nil ;; Alist: White player info
-         :black nil ;; Alist: Black player info
-         :my-color nil ;; Symbol: 'white, 'black, or nil (spectator)
-         :fen-history (make-vector 0 t) ;; Vector: History of FEN strings
-         :moves-str nil ;; String: Space-separated moves
-         :eval-cache (make-hash-table) ;; Hash: Local evaluation cache
-         :current-idx -1 ;; Integer: Current index in fen-history
-         :live-mode t ;; Boolean: t if following live game updates
-         :perspective 'white ;; Symbol: 'white or 'black board orientation
-         :speed nil ;; String: Game speed class (e.g. "blitz")
-         :status nil ;; String: Game status (e.g. "started", "mate")
-         :selected-square nil ;; Symbol: Currently selected square (e.g. 'e4)
-         :winner nil ;; Symbol: 'white, 'black, or nil
-         :white-clock "--:--" ;; String: Formatted white clock time
-         :black-clock "--:--" ;; String: Formatted black clock time
-         :white-time-ms nil ;; Number: White time in milliseconds
-         :black-time-ms nil ;; Number: Black time in milliseconds
-         :last-update-time nil ;; Number: Timestamp (float-time) of last update
-         :timer nil))) ;; Timer: Active timer object for polling/tick
-    ;; Apply overrides
-    (while args
-      (let ((key (pop args))
-            (val (pop args)))
-        (plist-put defaults key val)))
-    defaults))
+        (setf (lichess-game-fen-history state)
+              (vconcat hist (vector fen)))))))
 
 (defun lichess-game--reset-local-vars ()
   "Reset buffer-local state variables for a new game."
-  (setq-local lichess-game--state (lichess-game-create)))
+  (setq-local lichess-game--state
+              (make-lichess-game
+               :fen-history (make-vector 0 t)
+               :moves-str nil
+               :eval-cache (make-hash-table)
+               :current-idx -1
+               :live-mode t
+               :perspective 'white
+               :selected-square nil
+               :white-clock "--:--"
+               :black-clock "--:--"
+               :white-time-ms nil
+               :black-time-ms nil
+               :last-update-time nil
+               :timer nil)))
 
 (defun lichess-game--format-time (millis)
   "Format MILLIS (number) into MM:SS string."
@@ -231,14 +199,14 @@ immediately after the initial summary state."
   (when (buffer-live-p buf)
     (with-current-buffer buf
       (when-let* ((state lichess-game--state)
-                  (live (plist-get state :live-mode))
-                  (last-t (plist-get state :last-update-time))
-                  (w-ms (plist-get state :white-time-ms))
-                  (b-ms (plist-get state :black-time-ms)))
+                  (live (lichess-game-live-mode state))
+                  (last-t (lichess-game-last-update-time state))
+                  (w-ms (lichess-game-white-time-ms state))
+                  (b-ms (lichess-game-black-time-ms state)))
 
         ;; Determine who is moving
-        (let* ((hist (plist-get state :fen-history))
-               (idx (or (plist-get state :current-idx) -1))
+        (let* ((hist (lichess-game-fen-history state))
+               (idx (or (lichess-game-current-idx state) -1))
                (fen
                 (if (and (>= idx 0) (< idx (length hist)))
                     (aref hist idx)
@@ -247,7 +215,7 @@ immediately after the initial summary state."
                 (and fen
                      (ignore-errors
                        (lichess-fen-parse fen))))
-               (stm (and pos (plist-get pos :stm)))
+               (stm (and pos (lichess-pos-stm pos)))
                (now (float-time))
                (elapsed-ms (* (- now last-t) 1000)))
 
@@ -259,20 +227,18 @@ immediately after the initial summary state."
                   (setq new-w (max 0 (- w-ms elapsed-ms)))
                 (setq new-b (max 0 (- b-ms elapsed-ms))))
 
-              (plist-put
-               state
-               :white-clock (lichess-game--format-time new-w))
-              (plist-put
-               state
-               :black-clock (lichess-game--format-time new-b))
+              (setf (lichess-game-white-clock state)
+                    (lichess-game--format-time new-w))
+              (setf (lichess-game-black-clock state)
+                    (lichess-game--format-time new-b))
 
               ;; Optimization: Try to update clock in-place to avoid flickering
               (let ((updated-w
                      (lichess-game--update-clock-in-place
-                      'white (plist-get state :white-clock)))
+                      'white (lichess-game-white-clock state)))
                     (updated-b
                      (lichess-game--update-clock-in-place
-                      'black (plist-get state :black-clock))))
+                      'black (lichess-game-black-clock state))))
                 ;; If in-place update failed (e.g. text props lost), do full render
                 (unless (and updated-w updated-b)
                   (lichess-game-render))))))))))
@@ -299,9 +265,8 @@ Returns t if successful, nil otherwise."
   (with-current-buffer buf
     (when lichess-game--state
       (lichess-game--stop-timer buf)
-      (plist-put
-       lichess-game--state
-       :timer (run-at-time 1.0 1.0 #'lichess-game--tick buf)))))
+      (setf (lichess-game-timer lichess-game--state)
+            (run-at-time 1.0 1.0 #'lichess-game--tick buf)))))
 
 (defun lichess-game--stop-timer (&optional buf)
   "Stop the clock ticker for BUF (defaults to current)."
@@ -309,9 +274,9 @@ Returns t if successful, nil otherwise."
     (when (buffer-live-p b)
       (with-current-buffer b
         (when (and lichess-game--state
-                   (plist-get lichess-game--state :timer))
-          (cancel-timer (plist-get lichess-game--state :timer))
-          (plist-put lichess-game--state :timer nil))))))
+                   (lichess-game-timer lichess-game--state))
+          (cancel-timer (lichess-game-timer lichess-game--state))
+          (setf (lichess-game-timer lichess-game--state) nil))))))
 
 (defun lichess-game--stream-on-open (id buf msg-prefix _proc _buf)
   "Callback for NDJSON stream open.
@@ -321,7 +286,7 @@ ID is the game, BUF is the buffer, MSG-PREFIX for status."
    (unless (derived-mode-p 'lichess-game-buffer-mode)
      (lichess-game-buffer-mode))
    (lichess-game--reset-local-vars)
-   (plist-put lichess-game--state :id id)
+   (setf (lichess-game-id lichess-game--state) id)
    (erase-buffer)
    (insert (format "%s %s…\n" msg-prefix id))
    (lichess-game--start-timer buf)))
@@ -340,22 +305,21 @@ BUF is the target buffer, OBJ is the parsed JSON event."
         (black (lichess-util--aget players 'black))
         (state lichess-game--state)
         ;; Capture live mode BEFORE status update (which might clear it)
-        (was-live (plist-get state :live-mode)))
+        (was-live (lichess-game-live-mode state)))
 
      ;; [FIX] Update Moves (Incremental from 'lm')
      (when-let ((lm (lichess-util--aget obj 'lm)))
-       (let ((current (or (plist-get state :moves-str) "")))
-         (plist-put
-          state
-          :moves-str
-          (if (string-empty-p current)
-              lm
-            (concat current " " lm)))))
+       (let ((current (or (lichess-game-moves-str state) "")))
+         (setf (lichess-game-moves-str state)
+               (if (string-empty-p current)
+                   lm
+                 (concat current " " lm)))))
 
      ;; Update names if found (usually in the first message)
      (when (or white black)
-       (plist-put state :white white)
-       (plist-put state :black black)
+       (setf
+        (lichess-game-white state) white
+        (lichess-game-black state) black)
        (lichess-game--insert-preamble buf white black))
 
      ;; Update Status/Winner
@@ -363,12 +327,12 @@ BUF is the target buffer, OBJ is the parsed JSON event."
 
      ;; Update Moves
      (when moves
-       (plist-put state :moves-str moves))
+       (setf (lichess-game-moves-str state) moves))
 
      ;; Update Clocks
      (lichess-game--update-clocks state obj)
 
-     (plist-put state :last-update-time (float-time))
+     (setf (lichess-game-last-update-time state) (float-time))
 
      ;; Render FEN or Status
      (if fen
@@ -376,10 +340,9 @@ BUF is the target buffer, OBJ is the parsed JSON event."
            (lichess-game--fen-history-vpush fen)
            ;; If we were live, or still are, update index to follow game.
            ;; If game just ended, was-live is true, live-mode is false.
-           (when (or was-live (plist-get state :live-mode))
-             (plist-put
-              state
-              :current-idx (1- (length (plist-get state :fen-history))))
+           (when (or was-live (lichess-game-live-mode state))
+             (setf (lichess-game-current-idx state)
+                   (1- (length (lichess-game-fen-history state))))
              (lichess-game-render)))
        ;; If no FEN (e.g. termination event), render if status changed
        (when (lichess-util--aget obj 'status)
@@ -399,80 +362,73 @@ BUF is the target buffer, OBJ is the parsed JSON event."
 
      ;; Update Clocks
      (lichess-game--update-clocks state obj)
-     (plist-put state :last-update-time (float-time))
+     (setf (lichess-game-last-update-time state) (float-time))
 
      (when moves
-       (plist-put state :moves-str moves))
+       (setf (lichess-game-moves-str state) moves))
 
      ;; Update Status/Winner
      (lichess-game--update-status state state-obj buf)
 
      ;; 1. Handle game setup
      (when (string= type "gameFull")
-       (let*
-           ((ifen
-             (or (lichess-util--aget obj 'initialFen) "startpos"))
-            (ipos (lichess-fen-parse ifen))
+       (let* ((ifen
+               (or (lichess-util--aget obj 'initialFen) "startpos"))
+              (ipos (lichess-fen-parse ifen))
 
-            (variant
-             (lichess-util--aget
-              (lichess-util--aget obj 'variant) 'key))
+              (variant
+               (lichess-util--aget
+                (lichess-util--aget obj 'variant) 'key))
 
-            (w-id (lichess-util--aget white 'id))
-            (b-id (lichess-util--aget black 'id))
-            ;; Determine my color by matching username/ID
-            (curr-user
-             (and (boundp 'lichess-username) lichess-username))
-            (am-white
-             (or (and curr-user
-                      (lichess-util--aget white 'name)
-                      (string-match-p
-                       curr-user
-                       (or (lichess-util--aget white 'name) "")))
-                 (and w-id curr-user (string= w-id curr-user))))
-            (am-black
-             (or (and curr-user
-                      (lichess-util--aget black 'name)
-                      (string-match-p
-                       curr-user
-                       (or (lichess-util--aget black 'name) "")))
-                 (and b-id curr-user (string= b-id curr-user))))
-            (my-col
-             (cond
+              (w-id (lichess-util--aget white 'id))
+              (b-id (lichess-util--aget black 'id))
+              ;; Determine my color by matching username/ID
+              (curr-user
+               (and (boundp 'lichess-username) lichess-username))
               (am-white
-               'white)
+               (or (and curr-user
+                        (lichess-util--aget white 'name)
+                        (string-match-p
+                         curr-user
+                         (or (lichess-util--aget white 'name) "")))
+                   (and w-id curr-user (string= w-id curr-user))))
               (am-black
-               'black)
-              ;; Fallback for AI games: if one side is AI, we are the other
-              ((lichess-util--aget white 'aiLevel)
-               'black)
-              ((lichess-util--aget black 'aiLevel)
-               'white)
-              (t
-               nil))))
+               (or (and curr-user
+                        (lichess-util--aget black 'name)
+                        (string-match-p
+                         curr-user
+                         (or (lichess-util--aget black 'name) "")))
+                   (and b-id curr-user (string= b-id curr-user))))
+              (my-col
+               (cond
+                (am-white
+                 'white)
+                (am-black
+                 'black)
+                (t
+                 nil))))
 
-         (plist-put state :initial-pos ipos)
-         (plist-put state :variant variant)
-         (plist-put state :white white)
-         (plist-put state :black black)
-         (plist-put state :my-color my-col)
-         (when my-col
-           (plist-put state :perspective my-col))
-         (plist-put state :id (lichess-util--aget obj 'id))
+         (setf
+          (lichess-game-initial-pos state) ipos
+          (lichess-game-variant state) variant
+          (lichess-game-white state) white
+          (lichess-game-black state) black
+          (lichess-game-my-color state) my-col
+          (lichess-game-id state) (lichess-util--aget obj 'id))
          (lichess-game--insert-preamble buf white black
                                         variant
                                         my-col)))
 
      ;; 2. Reconstruct FEN / Check Status
      (if (lichess-util--aget state-obj 'moves)
-         (when-let ((ipos (plist-get state :initial-pos)))
+         (when-let ((ipos (lichess-game-initial-pos state)))
            (let* ((current-pos (lichess-fen-apply-moves ipos moves))
                   (current-fen (lichess-fen-pos->fen current-pos)))
              (lichess-game--fen-history-vpush current-fen)
-             (plist-put
-              state
-              :current-idx (1- (length (plist-get state :fen-history))))
-             (lichess-game-render)))
+             (when (lichess-game-live-mode state)
+               (setf (lichess-game-current-idx state)
+                     (1- (length (lichess-game-fen-history state))))
+               (lichess-game-render))))
        ;; No moves, but status update?
        (when (lichess-util--aget state-obj 'status)
          (lichess-game-render))))))
@@ -499,7 +455,7 @@ BUF, MSG-PREFIX, and MSG describe the event."
 
     (setq lichess-game--stream
           (lichess-http-ndjson-open
-           (lichess-api-stream-game-url id)
+           (format "/api/stream/game/%s" id)
            :buffer-name (buffer-name buf)
            :on-open
            (apply-partially #'lichess-game--stream-on-open
@@ -521,11 +477,12 @@ This uses /api/board/game/stream/{ID} which has no delay."
     (lichess-game-stream-stop)
     (setq lichess-game--stream
           (lichess-http-ndjson-open
-           (lichess-api-stream-game-board-url id)
+           (format "/api/board/game/stream/%s" id)
            :buffer-name (buffer-name buf)
            :on-open
-           (apply-partially #'lichess-game--stream-on-open
-                            id buf "Connecting to your game")
+           (apply-partially
+            #'lichess-game--stream-on-open
+            id buf "Connecting to your game (Zero-delay)")
            :on-event
            (apply-partially #'lichess-game--board-on-event buf)
            :on-close
@@ -540,14 +497,12 @@ This uses /api/board/game/stream/{ID} which has no delay."
   (let ((game-buf (current-buffer))
         (state lichess-game--state))
     (when state
-      (let ((hist (plist-get state :fen-history)))
+      (let ((hist (lichess-game-fen-history state)))
         (message "Batch fetching evaluations for %d moves..."
                  (length hist))
-        (lichess-announce-event
-         (format "Fetching evaluations for %d moves" (length hist)))
         (dotimes (i (length hist))
           (let ((cached-eval
-                 (gethash i (plist-get state :eval-cache))))
+                 (gethash i (lichess-game-eval-cache state))))
             (when (or (null cached-eval)
                       (and (stringp cached-eval)
                            (or (string-empty-p cached-eval)
@@ -557,15 +512,15 @@ This uses /api/board/game/stream/{ID} which has no delay."
                       (ignore-errors
                         (lichess-fen-parse fen))))
                 (when pos
-                  (puthash i :pending (plist-get state :eval-cache))
+                  (puthash i :pending (lichess-game-eval-cache state))
                   (lichess-util-fetch-evaluation
                    fen
                    (lambda (eval-str)
                      (lichess-core-with-buf
                       game-buf
                       (puthash
-                       i eval-str (plist-get state :eval-cache))
-                      (when (= i (plist-get state :current-idx))
+                       i eval-str (lichess-game-eval-cache state))
+                      (when (= i (lichess-game-current-idx state))
                         (lichess-game-render))))))))))))))
 
 ;;;###autoload
@@ -573,8 +528,8 @@ This uses /api/board/game/stream/{ID} which has no delay."
   "Set the board perspective for the current game buffer."
   (interactive)
   (when-let* ((state lichess-game--state)
-              (idx (plist-get state :current-idx))
-              (hist (plist-get state :fen-history)))
+              (idx (lichess-game-current-idx state))
+              (hist (lichess-game-fen-history state)))
     (let* ((choices '("auto" "white" "black"))
            (new-persp-str
             (completing-read "Set perspective: " choices
@@ -584,9 +539,7 @@ This uses /api/board/game/stream/{ID} which has no delay."
                              nil
                              "auto"))
            (new-persp (intern new-persp-str)))
-      (plist-put state :perspective new-persp)
-      (lichess-announce-event
-       (format "Perspective set to %s" new-persp-str))
+      (setf (lichess-game-perspective state) new-persp)
       (when idx
         (lichess-core-with-buf
          (current-buffer) (lichess-game-render))))))
@@ -595,14 +548,12 @@ This uses /api/board/game/stream/{ID} which has no delay."
   "Toggle the board perspective between white and black."
   (interactive)
   (when-let* ((state lichess-game--state))
-    (let* ((current (or (plist-get state :perspective) 'white))
+    (let* ((current (or (lichess-game-perspective state) 'white))
            (new-persp
             (if (eq current 'white)
                 'black
               'white)))
-      (plist-put state :perspective new-persp)
-      (lichess-announce-event
-       (format "Board flipped to %s" new-persp))
+      (setf (lichess-game-perspective state) new-persp)
       (lichess-game-render))))
 
 ;;;###autoload
@@ -613,8 +564,7 @@ This uses /api/board/game/stream/{ID} which has no delay."
       (progn
         (lichess-http-ndjson-close lichess-game--stream)
         (setq lichess-game--stream nil)
-        (message "Lichess NDJSON stream stopped.")
-        (lichess-announce-event "NDJSON stream stopped"))
+        (message "Lichess NDJSON stream stopped."))
     (message "No active Lichess NDJSON stream.")))
 
 ;;;###autoload
@@ -623,12 +573,12 @@ This uses /api/board/game/stream/{ID} which has no delay."
 MOVE should be in UCI format (e.g., e2e4)."
   (interactive "sMove (UCI, e.g. e2e4): ")
   (unless (and lichess-game--state
-               (plist-get lichess-game--state :id))
+               (lichess-game-id lichess-game--state))
     (error "No game ID found for this buffer"))
-  (let ((game-id (plist-get lichess-game--state :id)))
+  (let ((game-id (lichess-game-id lichess-game--state)))
     (message "Sending move %s for game %s..." move game-id)
-    (lichess-api-board-move
-     game-id move
+    (lichess-http-request
+     (format "/api/board/game/%s/move/%s" game-id move)
      (lambda (res)
        (let ((status (car res))
              (json (cdr res)))
@@ -636,61 +586,58 @@ MOVE should be in UCI format (e.g., e2e4)."
              (message "Move %s sent successfully" move)
            (message "Error sending move: %d %s"
                     status
-                    (or (lichess-util--aget json 'error) ""))))))))
+                    (or (lichess-util--aget json 'error) "")))))
+     :method "POST")))
 
 ;;;###autoload
 (defun lichess-game-resign ()
   "Resign the current game."
   (interactive)
   (unless (and lichess-game--state
-               (plist-get lichess-game--state :id))
+               (lichess-game-id lichess-game--state))
     (error "No game ID found for this buffer"))
   (when (yes-or-no-p "Really resign this game? ")
-    (let ((game-id (plist-get lichess-game--state :id)))
+    (let ((game-id (lichess-game-id lichess-game--state)))
       (message "Resigning game %s..." game-id)
-      (lichess-api-board-resign
-       game-id
+      (lichess-http-request
+       (format "/api/board/game/%s/resign" game-id)
        (lambda (res)
          (let ((status (car res))
                (json (cdr res)))
            (if (= status 200)
-               (progn
-                 (let ((msg "Game resign event sent"))
-                   (message msg)
-                   (lichess-announce-event msg))))
-           (message "Error resigning: %d %s"
-                    status
-                    (or (lichess-util--aget json 'error) ""))))))))
+               (message "Game resigned.")
+             (message "Error resigning: %d %s"
+                      status
+                      (or (lichess-util--aget json 'error) "")))))
+       :method "POST"))))
 
 ;;;###autoload
 (defun lichess-game-draw ()
   "Propose or accept a draw in the current game."
   (interactive)
   (unless (and lichess-game--state
-               (plist-get lichess-game--state :id))
+               (lichess-game-id lichess-game--state))
     (error "No game ID found for this buffer"))
   (when (yes-or-no-p "Offer/Accept draw? ")
-    (let ((game-id (plist-get lichess-game--state :id)))
+    (let ((game-id (lichess-game-id lichess-game--state)))
       (message "Sending draw request for game %s..." game-id)
-      (lichess-api-board-draw
-       game-id 'yes
+      (lichess-http-request
+       (format "/api/board/game/%s/draw/yes" game-id)
        (lambda (res)
          (let ((status (car res))
                (json (cdr res)))
            (if (= status 200)
-               (progn
-                 (let ((msg "Draw request sent"))
-                   (message msg)
-                   (lichess-announce-event msg)))
+               (message "Draw request sent/accepted.")
              (message "Error with draw request: %d %s"
                       status
-                      (or (lichess-util--aget json 'error) "")))))))))
+                      (or (lichess-util--aget json 'error) "")))))
+       :method "POST"))))
 
 (defun lichess-game--get-castling-move (color side)
   "Return UCI castling move string for COLOR and SIDE."
   (when-let* ((state lichess-game--state)
-              (variant (or (plist-get state :variant) "standard"))
-              (initial-pos (plist-get state :initial-pos)))
+              (variant (or (lichess-game-variant state) "standard"))
+              (initial-pos (lichess-game-initial-pos state)))
     (let ((is-960 (string= variant "chess960"))
           (row
            (if (eq color 'white)
@@ -706,7 +653,7 @@ MOVE should be in UCI format (e.g., e2e4)."
             (`(black . queenside) "e8c8"))
 
         ;; Chess960 Logic
-        (when-let* ((board (plist-get initial-pos :board))
+        (when-let* ((board (lichess-pos-board initial-pos))
                     (row-vec (aref board row))
                     (king-col
                      (cl-position
@@ -736,15 +683,15 @@ MOVE should be in UCI format (e.g., e2e4)."
 (defun lichess-game--do-castle (side)
   "Perform castling for SIDE (symbols `kingside' or `queenside')."
   (unless (and lichess-game--state
-               (plist-get lichess-game--state :id))
+               (lichess-game-id lichess-game--state))
     (error "No game ID"))
   (let* ((state lichess-game--state)
-         (hist (plist-get state :fen-history))
+         (hist (lichess-game-fen-history state))
          (last-fen
           (and (> (length hist) 0) (aref hist (1- (length hist)))))
          (pos (and last-fen (lichess-fen-parse last-fen)))
-         (my-color (plist-get state :my-color))
-         (turn (and pos (plist-get pos :stm)))
+         (my-color (lichess-game-my-color state))
+         (turn (and pos (lichess-pos-stm pos)))
          (fen-color
           (if (eq turn 'w)
               'white
@@ -768,14 +715,12 @@ MOVE should be in UCI format (e.g., e2e4)."
 (defun lichess-game-castle-kingside ()
   "Castle Kingside (O-O)."
   (interactive)
-  (lichess-announce-event "Kingside castle requested")
   (lichess-game--do-castle 'kingside))
 
 ;;;###autoload
 (defun lichess-game-castle-queenside ()
   "Castle Queenside (O-O-O)."
   (interactive)
-  (lichess-announce-event "Queenside castle requested")
   (lichess-game--do-castle 'queenside))
 
 
@@ -798,17 +743,17 @@ MOVE should be in UCI format (e.g., e2e4)."
   "Set current history index to IDX."
   (interactive "nIndex: ")
   (when-let* ((state lichess-game--state)
-              (hist (plist-get state :fen-history)))
+              (hist (lichess-game-fen-history state)))
     (when (and (>= idx 0) (< idx (length hist)))
-      (plist-put state :live-mode (= idx (1- (length hist))))
-      (plist-put state :current-idx idx)
+      (setf (lichess-game-live-mode state) (= idx (1- (length hist))))
+      (setf (lichess-game-current-idx state) idx)
       (lichess-game-render))))
 
 (defun lichess-game--insert-pgn (state game-buf)
   "Insert clickable PGN into current buffer for STATE and GAME-BUF."
-  (let* ((moves-str (or (plist-get state :moves-str) ""))
+  (let* ((moves-str (or (lichess-game-moves-str state) ""))
          (moves (split-string moves-str " " t))
-         (curr-idx (or (plist-get state :current-idx) -1))
+         (curr-idx (or (lichess-game-current-idx state) -1))
          ;; curr-idx 0 = startpos. 1 = after move 0.
          (highlight-idx (1- curr-idx)))
     (dotimes (i (length moves))
@@ -849,7 +794,7 @@ MOVE should be in UCI format (e.g., e2e4)."
   (when (buffer-live-p game-buf)
     (with-current-buffer game-buf
       (when-let* ((state lichess-game--state)
-                  (id (plist-get state :id)))
+                  (id (lichess-game-id state)))
         (let ((side-buf
                (get-buffer-create
                 (lichess-game--sidebar-buffer-name id))))
@@ -875,7 +820,7 @@ MOVE should be in UCI format (e.g., e2e4)."
   (unless (derived-mode-p 'lichess-game-buffer-mode)
     (error "Not in a Lichess game buffer"))
   (when-let* ((state lichess-game--state)
-              (id (plist-get state :id)))
+              (id (lichess-game-id state)))
     (let* ((side-name (lichess-game--sidebar-buffer-name id))
            (side-win (get-buffer-window side-name)))
       (if side-win
@@ -891,25 +836,25 @@ MOVE should be in UCI format (e.g., e2e4)."
 (defun lichess-game-handle-click (coord)
   "Handle a click on COORD (symbol like `e4') in the current game."
   (when-let* ((state lichess-game--state)
-              (selected (plist-get state :selected-square)))
+              (selected (lichess-game-selected-square state)))
     (cond
      ;; 1. Clicked the same square -> Deselect
      ((eq coord selected)
-      (plist-put state :selected-square nil)
+      (setf (lichess-game-selected-square state) nil)
       (lichess-game-render))
 
      ;; 2. Clicked a different square -> Attempt Move
      (t
       (let* ((move-str (format "%s%s" selected coord)))
-        (plist-put state :selected-square nil)
+        (setf (lichess-game-selected-square state) nil)
         (lichess-game-render)
         (lichess-game-move move-str)))))
 
   ;; If nothing selected, select the clicked square
   (unless (and lichess-game--state
-               (plist-get lichess-game--state :selected-square))
+               (lichess-game-selected-square lichess-game--state))
     (when lichess-game--state
-      (plist-put lichess-game--state :selected-square coord)
+      (setf (lichess-game-selected-square lichess-game--state) coord)
       (lichess-game-render))))
 
 (defun lichess-game-mouse-handler (event)
@@ -935,7 +880,7 @@ EVENT is the mouse event."
       (let* ((c (car col-row))
              (r (cdr col-row))
              (state lichess-game--state)
-             (persp (or (plist-get state :perspective) 'white))
+             (persp (or (lichess-game-perspective state) 'white))
              ;; Adjust for perspective
              ;; If black perspective, board is flipped.
              ;; Visually (0,0) is top-left.
@@ -970,34 +915,15 @@ Stop the clock in BUF if the game ended."
             raw-status))
          (winner (lichess-util--aget obj 'winner)))
     (when status
-      (plist-put state :status status))
+      (setf (lichess-game-status state) status))
     (when winner
       ;; 'winner' in JSON is usually "white" or "black" string
-      (plist-put
-       state
-       :winner
-       (if (stringp winner)
-           (intern winner)
-         winner)))
+      (setf (lichess-game-winner state) (intern winner)))
 
     ;; Stop clock if game ended
     (when (and status (not (string= status "started")))
-      (plist-put state :live-mode nil)
-      (lichess-game--stop-timer buf)
-      (let ((winner-name
-             (cond
-              ((stringp winner)
-               winner)
-              ((and winner (symbolp winner))
-               (symbol-name winner))
-              (t
-               nil))))
-        (lichess-announce-event
-         (format "Game %s. %s"
-                 status
-                 (if winner-name
-                     (format "%s won" (capitalize winner-name))
-                   "")))))))
+      (setf (lichess-game-live-mode state) nil)
+      (lichess-game--stop-timer buf))))
 
 (defun lichess-game--update-clocks (state obj)
   "Update clock times in STATE from OBJ.
@@ -1030,20 +956,18 @@ or `state.wtime' (ms)."
             sb))))
 
     (when (numberp final-w)
-      (plist-put
-       state
-       :white-clock (lichess-game--format-time final-w))
-      (plist-put state :white-time-ms final-w))
+      (setf (lichess-game-white-clock state)
+            (lichess-game--format-time final-w))
+      (setf (lichess-game-white-time-ms state) final-w))
     (when (numberp final-b)
-      (plist-put
-       state
-       :black-clock (lichess-game--format-time final-b))
-      (plist-put state :black-time-ms final-b))))
+      (setf (lichess-game-black-clock state)
+            (lichess-game--format-time final-b))
+      (setf (lichess-game-black-time-ms state) final-b))))
 
 (defun lichess-game--format-result (state)
   "Format the game result string from STATE for the footer."
-  (let* ((status (plist-get state :status))
-         (winner (plist-get state :winner))
+  (let* ((status (lichess-game-status state))
+         (winner (lichess-game-winner state))
          (score
           (cond
            ((eq winner 'white)
@@ -1073,10 +997,12 @@ or `state.wtime' (ms)."
 (defun lichess-game--format-header (state)
   "Format the game header strings (names, clocks) from STATE.
 Returns a cons cell (TOP . BOTTOM) based on board perspective."
-  (let* ((w-name (lichess-util-fmt-user-obj (plist-get state :white)))
-         (b-name (lichess-util-fmt-user-obj (plist-get state :black)))
-         (idx (plist-get state :current-idx))
-         (hist (plist-get state :fen-history))
+  (let* ((w-name
+          (lichess-util-fmt-user-obj (lichess-game-white state)))
+         (b-name
+          (lichess-util-fmt-user-obj (lichess-game-black state)))
+         (idx (lichess-game-current-idx state))
+         (hist (lichess-game-fen-history state))
          (fen
           (if (and idx (>= idx 0) (< idx (length hist)))
               (aref hist idx)
@@ -1094,12 +1020,12 @@ Returns a cons cell (TOP . BOTTOM) based on board perspective."
               (cdr mat-strings)
             ""))
          (w-clock-str
-          (propertize (or (plist-get state :white-clock) "--:--")
+          (propertize (or (lichess-game-white-clock state) "--:--")
                       'lichess-clock 'white 'face 'bold))
          (b-clock-str
-          (propertize (or (plist-get state :black-clock) "--:--")
+          (propertize (or (lichess-game-black-clock state) "--:--")
                       'lichess-clock 'black 'face 'bold))
-         (perspective (plist-get state :perspective))
+         (perspective (lichess-game-perspective state))
          (white-line (format "%s%s  %s" w-name w-mat w-clock-str))
          (black-line (format "%s%s  %s" b-name b-mat b-clock-str)))
     (if (eq perspective 'black)
@@ -1118,7 +1044,7 @@ Returns a cons cell (TOP . BOTTOM) based on board perspective."
                  'action
                  (lambda (_) (lichess-game-flip-board)))
   (insert "  ")
-  (when (plist-get state :my-color)
+  (when (lichess-game-my-color state)
     (insert-button "[Resign]"
                    'action
                    (lambda (_) (lichess-game-resign)))
